@@ -15,8 +15,10 @@
 
 mod buffered_serializing_stream;
 mod csv;
+mod display_stream;
 mod json;
 mod lazy_data;
+mod middleware_from_fn;
 mod ndjson;
 mod redirect;
 mod utils;
@@ -24,5 +26,6 @@ mod utils;
 // public API
 pub mod extract;
 pub mod guard;
+pub mod middleware;
 pub mod respond;
 pub mod web;
