@@ -19,7 +19,7 @@ use crate::{buffered_serializing_stream::BufferedSerializingStream, utils::MutWr
 static NDJSON_MIME: Lazy<Mime> = Lazy::new(|| "application/x-ndjson".parse().unwrap());
 
 pin_project! {
-    /// A buffered [NDJSON] serializing stream.
+    /// A buffered [NDJSON] serializing body stream.
     ///
     /// This has significant memory efficiency advantages over returning an array of JSON objects
     /// when the data set is very large because it avoids buffering the entire response.
@@ -64,10 +64,7 @@ where
 {
     /// Creates a chunked body stream that serializes as NDJSON on-the-fly.
     pub fn into_body_stream(self) -> impl MessageBody {
-        BodyStream::new(BufferedSerializingStream::new(
-            self.stream,
-            serialize_json_line,
-        ))
+        BodyStream::new(self.into_chunk_stream())
     }
 
     /// Creates a `Responder` type with a serializing stream and correct Content-Type header.
